@@ -11,7 +11,16 @@ except ImportError:
 import pytest
 from conftest import skip_if_pypy
 
-from pikepdf import Array, Dictionary, Name, Page, Pdf, PdfMatrix, Stream
+from pikepdf import (
+    Array,
+    Dictionary,
+    Name,
+    Page,
+    Pdf,
+    PdfMatrix,
+    Stream,
+    __libqpdf_version__,
+)
 from pikepdf._cpphelpers import label_from_label_dict
 
 # pylint: disable=redefined-outer-name,pointless-statement
@@ -227,12 +236,13 @@ def test_page_contents_add(graph, outdir):
     stream1 = Stream(pdf, b'q ' + mat.encode() + b' cm')
     stream2 = Stream(pdf, b'Q')
 
-    pdf.pages[0].page_contents_add(stream1, True)
-    pdf.pages[0].page_contents_add(stream2, False)
+    Page(pdf.pages[0]).contents_add(stream1, True)
+    Page(pdf.pages[0]).contents_add(stream2, False)
     pdf.save(outdir / 'out.pdf')
 
     with pytest.raises(TypeError, match="Not a Page"):
-        Array([42]).page_contents_add(stream1)
+        with pytest.deprecated_call():
+            Array([42]).page_contents_add(stream1)
 
 
 def test_bad_access(fourpages):
@@ -343,7 +353,7 @@ def test_add_foreign_twice(graph, outpdf):
     out.save(outpdf)
 
 
-@pytest.mark.xfail(reason="needs qpdf fix to issue 514")
+@pytest.mark.xfail(__libqpdf_version__ < '10.3.2', reason="qpdf issue 514")
 def test_add_twice_without_copy_foreign(graph, outpdf):
     out = Pdf.new()
     out.pages.append(graph.pages[0])
